"""
Daves utilities is a collection of useful python functions which I would like to
provide to anybody who is interested in using them.
"""
from daves_utilities.archive.fun_save import fun_save
from daves_utilities.archive.is_equal import is_equal
from daves_utilities.archive.print_structure import print_str
from daves_utilities.david_secrets import decrypt_message
from daves_utilities.david_secrets import encrypt_message
from daves_utilities.david_secrets import generate_key
from daves_utilities.iterator import for_long

__all__ = [
    "for_long",
    "fun_save",
    "is_equal",
    "print_str",
    "print_structure",
    "decrypt_message",
    "encrypt_message",
    "generate_key",
]



import os

from cryptography.fernet import Fernet

key = os.getenv("DAVID_SECRET")
fernet = Fernet(key)


def generate_key():
    return Fernet.generate_key()


def encrypt_message(message):
    return fernet.encrypt(message.encode())


def decrypt_message(enc_message):
    return fernet.decrypt(enc_message).decode()


if __name__ == "__main__":
    message = "this is a test"
    print(f"{message=}")

    enc_message = encrypt_message(message)
    print(f"{enc_message=}")

    dec_message = decrypt_message(enc_message)
    print(f"{dec_message=}")



access = {
    "postgres":{
        "postgres_usr": 'ti',
        "postgres_pwd": (
            'gAAAAABk_1-X_7CiiUj5MIlXyYVGdFB90RKJPblTLgUNOaFtyaXZmoMzpF6h2'
            'KyQu2TrKgjJBmdPwJtQvySgR0bHlYqJR9oHPw=='
        )
    },
}
